==> kubernetes-model-apiextensions-5.2.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionStatusFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface CustomResourceDefinitionStatusFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAcceptedNames instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames getAcceptedNames();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames buildAcceptedNames();
    public A withAcceptedNames(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames acceptedNames);
    public Boolean hasAcceptedNames();
    public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNames();
    public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNamesLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames item);
    public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editAcceptedNames();
    public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNames();
    public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNamesLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames item);
    public A addToConditions(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition item);
    public A setToConditions(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition item);
    public A addToConditions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition... items);
    public A addAllToConditions(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition> items);
    public A removeFromConditions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition... items);
    public A removeAllFromConditions(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition> items);
    public A removeMatchingFromConditions(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition> getConditions();
    public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition> buildConditions();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition buildCondition(int index);
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition buildFirstCondition();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition buildLastCondition();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition buildMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionConditionBuilder> predicate);
    public A withConditions(List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition> conditions);
    public A withConditions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition... conditions);
    public Boolean hasConditions();
    public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewCondition();
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition item);
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> setNewConditionLike(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition item);
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editCondition(int index);
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editFirstCondition();
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editLastCondition();
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionConditionBuilder> predicate);
    public A addToStoredVersions(int index,String item);
    public A setToStoredVersions(int index,String item);
    public A addToStoredVersions(String... items);
    public A addAllToStoredVersions(Collection<String> items);
    public A removeFromStoredVersions(String... items);
    public A removeAllFromStoredVersions(Collection<String> items);
    public List<String> getStoredVersions();
    public String getStoredVersion(int index);
    public String getFirstStoredVersion();
    public String getLastStoredVersion();
    public String getMatchingStoredVersion(Predicate<String> predicate);
    public Boolean hasMatchingStoredVersion(Predicate<String> predicate);
    public A withStoredVersions(List<String> storedVersions);
    public A withStoredVersions(String... storedVersions);
    public Boolean hasStoredVersions();
    public A addNewStoredVersion(String arg1);
    public A addNewStoredVersion(StringBuilder arg1);
    public A addNewStoredVersion(StringBuffer arg1);
    public interface AcceptedNamesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<CustomResourceDefinitionStatusFluent.AcceptedNamesNested<N>> {

            public N and();
            public N endAcceptedNames();    }


    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionConditionFluent<CustomResourceDefinitionStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


}

==> kubernetes-model-apiextensions-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1beta1/CustomResourceDefinitionStatusFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface CustomResourceDefinitionStatusFluent<A extends io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildAcceptedNames instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames getAcceptedNames();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames buildAcceptedNames();
    public A withAcceptedNames(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames acceptedNames);
    public Boolean hasAcceptedNames();
    public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNames();
    public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> withNewAcceptedNamesLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames item);
    public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editAcceptedNames();
    public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNames();
    public CustomResourceDefinitionStatusFluent.AcceptedNamesNested<A> editOrNewAcceptedNamesLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNames item);
    public A addToConditions(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition item);
    public A setToConditions(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition item);
    public A addToConditions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition... items);
    public A addAllToConditions(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition> items);
    public A removeFromConditions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition... items);
    public A removeAllFromConditions(Collection<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition> items);
    public A removeMatchingFromConditions(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition> getConditions();
    public List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition> buildConditions();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition buildCondition(int index);
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition buildFirstCondition();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition buildLastCondition();
    public io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition buildMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionConditionBuilder> predicate);
    public A withConditions(List<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition> conditions);
    public A withConditions(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition... conditions);
    public Boolean hasConditions();
    public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewCondition();
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition item);
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> setNewConditionLike(int index,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionCondition item);
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editCondition(int index);
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editFirstCondition();
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editLastCondition();
    public CustomResourceDefinitionStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionConditionBuilder> predicate);
    public A addToStoredVersions(int index,String item);
    public A setToStoredVersions(int index,String item);
    public A addToStoredVersions(String... items);
    public A addAllToStoredVersions(Collection<String> items);
    public A removeFromStoredVersions(String... items);
    public A removeAllFromStoredVersions(Collection<String> items);
    public List<String> getStoredVersions();
    public String getStoredVersion(int index);
    public String getFirstStoredVersion();
    public String getLastStoredVersion();
    public String getMatchingStoredVersion(Predicate<String> predicate);
    public Boolean hasMatchingStoredVersion(Predicate<String> predicate);
    public A withStoredVersions(List<String> storedVersions);
    public A withStoredVersions(String... storedVersions);
    public Boolean hasStoredVersions();
    public A addNewStoredVersion(StringBuilder arg1);
    public A addNewStoredVersion(int[] arg1,int arg2,int arg3);
    public A addNewStoredVersion(char[] arg1);
    public A addNewStoredVersion(StringBuffer arg1);
    public A addNewStoredVersion(byte[] arg1,int arg2);
    public A addNewStoredVersion(byte[] arg1);
    public A addNewStoredVersion(char[] arg1,int arg2,int arg3);
    public A addNewStoredVersion(byte[] arg1,int arg2,int arg3);
    public A addNewStoredVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewStoredVersion(String arg1);
    public interface AcceptedNamesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionNamesFluent<CustomResourceDefinitionStatusFluent.AcceptedNamesNested<N>> {

            public N and();
            public N endAcceptedNames();    }


    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.apiextensions.v1beta1.CustomResourceDefinitionConditionFluent<CustomResourceDefinitionStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


}
